#include <Windows.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "oakexport.h"

HMODULE    nHandle=NULL;
poakBegin  oakBegin;
poakEnd    oakEnd;
poakExport oakExport;
poakSetOption oakSetOption;
poakGetOption oakGetOption;

BOOL LoadDLL();
void FreeDLL();


/*------------------------------------------------------------------------------------------------------
 Load dynamic link library---pstoimage.dll
------------------------------------------------------------------------------------------------------*/
BOOL LoadDLL()
{
	nHandle=LoadLibrary("pstoimage.dll");
	if( nHandle == NULL )
		goto Failer;

	oakBegin=(poakBegin)GetProcAddress(nHandle,"_oakBegin@0");
	if( oakBegin == NULL ) goto Failer;

	oakEnd=(poakEnd)GetProcAddress(nHandle,"_oakEnd@4");
	if( oakEnd == NULL ) goto Failer;

	oakExport = (poakExport)GetProcAddress(nHandle,"_oakExport@4");
	if( oakExport == NULL ) goto Failer;

	oakSetOption=(poakSetOption)GetProcAddress(nHandle,"_oakSetOption@24");
	if( oakSetOption == NULL ) goto Failer;

	oakGetOption=(poakGetOption)GetProcAddress(nHandle,"_oakGetOption@24");
	if( oakGetOption == NULL ) goto Failer;

	return TRUE;

Failer:
	FreeDLL(); 
	return FALSE;
}

/*------------------------------------------------------------------------------------------------------
 Free dynamic link library---pstoimage.dll
------------------------------------------------------------------------------------------------------*/
void FreeDLL()
{
	if( nHandle == NULL )
		return;

	FreeLibrary(nHandle);
	nHandle = NULL;	
}

/*******************************************************************************************************
 *  main() 
 *  function: This demo converts ps/eps file(s) to image files.
 *******************************************************************************************************/
int main()
{
	long id, iRet;
	long isMultiPage = TRUE;

	//Load dynamic link library---pstoimage.dll
	if( !LoadDLL() )
		exit(FALSE);

	//------------------------------------------------------------------------------------------------
	// Convert one ps/eps file to true color bmp file.
	//------------------------------------------------------------------------------------------------
	id = oakBegin();
	oakSetOption(id, OAK_Set_Input, 0, 0, "_test_01.ps", NULL); //input file.
	oakSetOption(id, OAK_Set_Output, OAK_FILE_BMP, 0, "mytest.bmp", NULL); //output format and file.
	oakSetOption(id, OAK_Set_DPI, 120, 120, NULL, NULL); //horizontal and vertical dpi.
	iRet = oakExport(id);
	oakEnd(id);
	//------------------------------------------------------------------------------------------------


	//------------------------------------------------------------------------------------------------
	// Convert one ps/eps file to grayscale jpeg file.
	//------------------------------------------------------------------------------------------------
	id = oakBegin();
	oakSetOption(id, OAK_Set_Input, 0, 0, "_test_02.eps", NULL); //input file.
	oakSetOption(id, OAK_Set_Output, OAK_FILE_JPG, 0, "mytest.jpeg", NULL); //output format and file.
	oakSetOption(id, OAK_Set_DPI, 120, 120, NULL, NULL); //horizontal and vertical dpi.
	oakSetOption(id, OAK_Set_Color, oak_color_8_g, 0, NULL, NULL); //grayscale jpeg
	oakSetOption(id, OAK_Set_Quality, 75, 0, NULL, NULL); //jpeg quality.
	iRet = oakExport(id);
	oakEnd(id);
	//------------------------------------------------------------------------------------------------


	//------------------------------------------------------------------------------------------------
	// Convert sevrial ps/eps files to a multi-page tiff file.
	//------------------------------------------------------------------------------------------------
	id = oakBegin();
	oakSetOption(id,OAK_Set_Input, 0, 0, "_test_01.ps", NULL); //input file.
	oakSetOption(id,OAK_Set_Input, 0, 0, "_test_02.eps", NULL); //input file.
	oakSetOption(id,OAK_Set_Output,OAK_FILE_TIF, isMultiPage, "mytest.tiff", NULL); //multi-page tiff
	oakSetOption(id, OAK_Set_DPI, 96, 96, NULL, NULL); //horizontal and vertical dpi.
	oakSetOption(id, OAK_Set_Compress, OAK_COMPRESSION_LZW, 0, NULL, NULL); //tiff compression
	iRet = oakExport(id);
	oakEnd(id);
	//------------------------------------------------------------------------------------------------


	//Free dynamic link library---pstoimage.dll
	FreeDLL();
	exit(TRUE);
}
